=======
Credits
=======

Development Lead
----------------

* Xuchen Yao <xuchen@kitt.ai>

Parsetron is inspired by `pyparsing <https://pyparsing.wikispaces.com/>`_.

Contributors
------------

None yet. Why not be the first?
